@@ -154,7 +154,7 @@ makedist()
 		if [ -n "$lib_dir" ]
 		then
 			mkdir -p $DISTLIB/debian-$arch
-			cp -R $lib_dir/ $DISTLIB/debian-$arch/
+			cp -R $lib_dir/* $DISTLIB/debian-$arch/
 		else
 			echo No corresponding files
 		fi
