@@ -1,5 +1,5 @@
-#ifndef __8MR190_2_4247
-#define __8MR190_2_4247
+#ifndef __8MR191_1_28
+#define __8MR191_1_28
 
 #include <string.h>
 
@@ -10,18 +10,18 @@
 #endif
 
 
-#define 8MR190_2_4247_BUILDER_VERSION_MAJOR  0
-#define 8MR190_2_4247_BUILDER_VERSION_MINOR  9
-#define 8MR190_2_4247_BUILDER_VERSION_BUGFIX 16
-#define 8MR190_2_4247_BUILDER_VERSION_SUFFIX ""
-#define 8MR190_2_4247_BUILDER_VERSION        "0.9.16"
+#define 8MR191_1_28_BUILDER_VERSION_MAJOR  0
+#define 8MR191_1_28_BUILDER_VERSION_MINOR  9
+#define 8MR191_1_28_BUILDER_VERSION_BUGFIX 16
+#define 8MR191_1_28_BUILDER_VERSION_SUFFIX ""
+#define 8MR191_1_28_BUILDER_VERSION        "0.9.16"
 
 
 #if defined(_MSC_VER)
 #define inline __inline
 #endif
 
-static inline result_t set_profile_8MR190_2_4247(device_t id)
+static inline result_t set_profile_8MR191_1_28(device_t id)
 {
   result_t worst_result = result_ok;
   result_t result = result_ok;
@@ -29,7 +29,7 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
   feedback_settings_t feedback_settings;
   memset((void*)&feedback_settings, 0, sizeof(feedback_settings_t));
   feedback_settings.IPS = 4000;
-  feedback_settings.FeedbackType = FEEDBACK_NONE;
+  feedback_settings.FeedbackType = FEEDBACK_EMF;
   feedback_settings.FeedbackFlags = FEEDBACK_ENC_TYPE_SINGLE_ENDED | FEEDBACK_ENC_TYPE_AUTO;
   feedback_settings.CountsPerTurn = 4000;
   result = set_feedback_settings(id, &feedback_settings);
@@ -48,9 +48,9 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
   home_settings.uFastHome = 0;
   home_settings.SlowHome = 10;
   home_settings.uSlowHome = 0;
-  home_settings.HomeDelta = 3000;
+  home_settings.HomeDelta = -1000;
   home_settings.uHomeDelta = 0;
-  home_settings.HomeFlags = HOME_USE_FAST | HOME_STOP_SECOND_REV | HOME_STOP_FIRST_BITS | HOME_DIR_SECOND;
+  home_settings.HomeFlags = HOME_USE_FAST | HOME_STOP_SECOND_REV | HOME_STOP_FIRST_BITS | HOME_DIR_FIRST;
   result = set_home_settings(id, &home_settings);
 
   if (result != result_ok)
@@ -63,11 +63,11 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
 
   move_settings_t move_settings;
   memset((void*)&move_settings, 0, sizeof(move_settings_t));
-  move_settings.Speed = 1000;
+  move_settings.Speed = 2000;
   move_settings.uSpeed = 0;
-  move_settings.Accel = 1000;
-  move_settings.Decel = 2000;
-  move_settings.AntiplaySpeed = 50;
+  move_settings.Accel = 2000;
+  move_settings.Decel = 5000;
+  move_settings.AntiplaySpeed = 2000;
   move_settings.uAntiplaySpeed = 0;
   move_settings.MoveFlags = 0;
   result = set_move_settings(id, &move_settings);
@@ -82,12 +82,12 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
 
   engine_settings_t engine_settings;
   memset((void*)&engine_settings, 0, sizeof(engine_settings_t));
-  engine_settings.NomVoltage = 1200;
-  engine_settings.NomCurrent = 1200;
+  engine_settings.NomVoltage = 360;
+  engine_settings.NomCurrent = 670;
   engine_settings.NomSpeed = 4800;
   engine_settings.uNomSpeed = 0;
   engine_settings.EngineFlags = ENGINE_LIMIT_RPM | ENGINE_ACCEL_ON;
-  engine_settings.Antiplay = 50;
+  engine_settings.Antiplay = 1800;
   engine_settings.MicrostepMode = MICROSTEP_MODE_FRAC_256;
   engine_settings.StepsPerRev = 200;
   result = set_engine_settings(id, &engine_settings);
@@ -120,7 +120,7 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
   power_settings.CurrReductDelay = 1000;
   power_settings.PowerOffDelay = 60;
   power_settings.CurrentSetTime = 300;
-  power_settings.PowerFlags = POWER_SMOOTH_CURRENT | POWER_OFF_ENABLED | POWER_REDUCT_ENABLED;
+  power_settings.PowerFlags = POWER_SMOOTH_CURRENT | POWER_REDUCT_ENABLED;
   result = set_power_settings(id, &power_settings);
 
   if (result != result_ok)
@@ -135,7 +135,7 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
   memset((void*)&secure_settings, 0, sizeof(secure_settings_t));
   secure_settings.LowUpwrOff = 800;
   secure_settings.CriticalIpwr = 4000;
-  secure_settings.CriticalUpwr = 5000;
+  secure_settings.CriticalUpwr = 5500;
   secure_settings.CriticalT = 800;
   secure_settings.CriticalIusb = 450;
   secure_settings.CriticalUusb = 520;
@@ -154,10 +154,10 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
   edges_settings_t edges_settings;
   memset((void*)&edges_settings, 0, sizeof(edges_settings_t));
   edges_settings.BorderFlags = 0;
-  edges_settings.EnderFlags = ENDER_SW2_ACTIVE_LOW | ENDER_SW1_ACTIVE_LOW;
-  edges_settings.LeftBorder = -2100;
+  edges_settings.EnderFlags = ENDER_SW2_ACTIVE_LOW | ENDER_SW1_ACTIVE_LOW | ENDER_SWAP;
+  edges_settings.LeftBorder = -34100;
   edges_settings.uLeftBorder = 0;
-  edges_settings.RightBorder = 32100;
+  edges_settings.RightBorder = 100;
   edges_settings.uRightBorder = 0;
   result = set_edges_settings(id, &edges_settings);
 
@@ -174,8 +174,8 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
   pid_settings.KpU = 0;
   pid_settings.KiU = 0;
   pid_settings.KdU = 0;
-  pid_settings.Kpf = 0.003599999938160181;
-  pid_settings.Kif = 0.03799999877810478;
+  pid_settings.Kpf = 0.006000000052154064;
+  pid_settings.Kif = 0.05000000074505806;
   pid_settings.Kdf = 2.8000000384054147e-05;
   result = set_pid_settings(id, &pid_settings);
 
@@ -255,9 +255,9 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
 
   control_settings_t control_settings;
   memset((void*)&control_settings, 0, sizeof(control_settings_t));
-  control_settings.MaxSpeed[0] = 100;
-  control_settings.MaxSpeed[1] = 1000;
-  control_settings.MaxSpeed[2] = 0;
+  control_settings.MaxSpeed[0] = 20;
+  control_settings.MaxSpeed[1] = 200;
+  control_settings.MaxSpeed[2] = 2000;
   control_settings.MaxSpeed[3] = 0;
   control_settings.MaxSpeed[4] = 0;
   control_settings.MaxSpeed[5] = 0;
@@ -353,9 +353,9 @@ static inline result_t set_profile_8MR190_2_4247(device_t id)
 
   emf_settings_t emf_settings;
   memset((void*)&emf_settings, 0, sizeof(emf_settings_t));
-  emf_settings.L = 0;
-  emf_settings.R = 0;
-  emf_settings.Km = 0;
+  emf_settings.L = 0.005400000140070915;
+  emf_settings.R = 7.400000095367432;
+  emf_settings.Km = 0.0024999999441206455;
   emf_settings.BackEMFFlags = BACK_EMF_KM_AUTO | BACK_EMF_RESISTANCE_AUTO | BACK_EMF_INDUCTANCE_AUTO;
   result = set_emf_settings(id, &emf_settings);
 
