@@ -1043,7 +1043,7 @@ result_t open_port_net(device_metadata_t *metadata, const char* host, const char
  *   xi-emu:///c:/temp/virtual56.dat
  *   xi-emu:///c:/temp/virtual56.dat?serial=123
  *   xi-net://127.0.0.1/7890ABCD
- *   xi-net://remote.ximc.ru/7890ABCD
+ *   xi-net://remote.xisupport.com/7890ABCD
  */
 result_t open_port (device_metadata_t *metadata, const char* name)
 {
@@ -1232,6 +1232,11 @@ result_t normal_correction(device_t* id, float* newPosition)
 
 	cPosition = *newPosition;
 	dm = get_metadata(*id);
+	if (!dm)
+	{
+		log_error(L"normal_correction cannot get metadata");
+		return 0;
+	}
 	correction = &(dm->table);	
 	
 	if ((dm->table.X == NULL) || (dm->table.dX == NULL))
@@ -1296,6 +1301,12 @@ result_t rewers_correction(device_t* id, float* newPosition)
 
 	cPosition = *newPosition;
 	dm = get_metadata(*id);
+	if (!dm)
+	{
+		log_error(L"rewers_correction cannot get metadata");
+		return 0;
+	}
+
 	correction = &(dm->table);
 
 	if ((dm->table.X == NULL) || (dm->table.dX == NULL))
