@@ -249,7 +249,7 @@ const wchar_t* loglevel_string_w (int loglevel)
 
 const int default_max_loglevel = LOGLEVEL_WARNING;
 
-int parse_uri_after_path(
+int parse_path_and_query(
 		const char *ppath,
 		char *path, size_t path_len,
 		char *paramname, size_t paramname_len,
@@ -257,16 +257,6 @@ int parse_uri_after_path(
 {
 	const char *p = ppath, *pn;
 
-	/*
-	 * Add platform-dependent path validation. We demand absolute path! For windows it must start with partitition letter followed
-	 * by ":\\" or ":/". Yes, let it be POSIX-slash-style compatible. #85091#note-28
-	 * Purpose of the following is to block allowed in fopen relative paths. User must be restricted!
-	 */
-	#ifdef _WIN32
-	if (!isalpha(p[0]) || p[1] != ':' || p[2] != '\\' && p[2] != '/') // In case of wrong absolute path
-		return 1;
-	#endif
-
 	// check is there a param
 	pn = strstr(p, "?");
 
@@ -359,8 +349,21 @@ int parse_uri(const char *name,
 		if (pn == p)
 		{
 			// no host part, only path (scheme:///path)
+			if (strcmp(scheme, "xi-emu") == 0)
+			{
+				/* A little kludge! In case of "xi-emu:///path" on Windows, we demand absolute path: "xi-emu:///C:\xxxx" #85091#note-28.
+				 *
+				 * Add platform-dependent path validation. We demand absolute path! For windows it must start with partition letter followed
+				 * by ":\\" or ":/". Yes, let it be POSIX-slash-style compatible.
+				 * Purpose of the following is to block allowed in fopen relative paths. User must be restricted!
+				 */
+				#ifdef _WIN32
+				if (!isalpha(p[1]) || p[2] != ':' || p[3] != '\\' && p[3] != '/') // In case of wrong absolute path
+					return 1;
+				#endif
+			}
 
-			if (parse_uri_after_path(p+1,
+			if (parse_path_and_query(p+1,
 						path, path_len,
 						paramname, paramname_len,
 						paramvalue, paramvalue_len))
@@ -374,7 +377,7 @@ int parse_uri(const char *name,
 			memcpy(host, p, pn-p);
 			host[pn-p] = 0;
 
-			if (parse_uri_after_path(pn+1,
+			if (parse_path_and_query(pn+1,
 						path, path_len,
 						paramname, paramname_len,
 						paramvalue, paramvalue_len))
