@@ -1,4 +1,4 @@
-def set_profile_8MID20_12_N(lib, id):
+def set_profile_8MID30_15_N(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -176,15 +176,15 @@ def set_profile_8MID20_12_N(lib, id):
         BORDER_STOP_RIGHT = 4
         BORDER_STOP_LEFT = 2
         BORDER_IS_ENCODER = 1
-    edges_settings.BorderFlags = BorderFlags_.BORDER_STOP_RIGHT | BorderFlags_.BORDER_STOP_LEFT
+    edges_settings.BorderFlags = BorderFlags_.BORDERS_SWAP_MISSET_DETECTION | BorderFlags_.BORDER_STOP_RIGHT | BorderFlags_.BORDER_STOP_LEFT
     class EnderFlags_:
         ENDER_SW2_ACTIVE_LOW = 4
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
     edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW | EnderFlags_.ENDER_SWAP
-    edges_settings.LeftBorder = -970
+    edges_settings.LeftBorder = -931
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 923
+    edges_settings.RightBorder = 2453
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
@@ -446,7 +446,7 @@ def set_profile_8MID20_12_N(lib, id):
     stage_information = stage_information_t()
 
     stage_information.Manufacturer = bytes([0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([56, 77, 73, 68, 50, 48, 45, 49, 46, 50, 45, 78, 0, 0, 53, 0, 0, 52, 48, 68, 45, 69, 65, 83])
+    stage_information.PartNumber = bytes([56, 77, 73, 68, 51, 48, 45, 49, 46, 53, 45, 78, 0, 0, 53, 0, 0, 52, 48, 68, 45, 69, 65, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
@@ -458,7 +458,7 @@ def set_profile_8MID20_12_N(lib, id):
     stage_settings.LeadScrewPitch = 0.25
     stage_settings.Units = bytes([0, 109, 0, 114, 101, 101, 0, 0])
     stage_settings.MaxSpeed = 0
-    stage_settings.TravelRange = 18.799999237060547
+    stage_settings.TravelRange = 28.5
     stage_settings.SupplyVoltageMin = 0
     stage_settings.SupplyVoltageMax = 0
     stage_settings.MaxCurrentConsumption = 0
@@ -581,8 +581,8 @@ def set_profile_8MID20_12_N(lib, id):
 
     gear_settings = gear_settings_t()
 
-    gear_settings.ReductionIn = 53
-    gear_settings.ReductionOut = 40
+    gear_settings.ReductionIn = 25
+    gear_settings.ReductionOut = 16
     gear_settings.RatedInputTorque = 0
     gear_settings.RatedInputSpeed = 0
     gear_settings.MaxOutputBacklash = 0
