@@ -1,4 +1,4 @@
-def set_profile_8MR190_2_4233(lib, id):
+def set_profile_8MR190_90_4247(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -74,8 +74,8 @@ def set_profile_8MR190_2_4233(lib, id):
     engine_settings = engine_settings_t()
 
     engine_settings.NomVoltage = 1
-    engine_settings.NomCurrent = 400
-    engine_settings.NomSpeed = 4800
+    engine_settings.NomCurrent = 1200
+    engine_settings.NomSpeed = 2400
     engine_settings.uNomSpeed = 0
     class EngineFlags_:
         ENGINE_LIMIT_RPM = 128
@@ -86,7 +86,7 @@ def set_profile_8MR190_2_4233(lib, id):
         ENGINE_MAX_SPEED = 4
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
-    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON
+    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_REVERSE
     engine_settings.Antiplay = 575
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
@@ -182,9 +182,9 @@ def set_profile_8MR190_2_4233(lib, id):
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
     edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW
-    edges_settings.LeftBorder = -2100
+    edges_settings.LeftBorder = -2400
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 32100
+    edges_settings.RightBorder = 20400
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
